==> jc-1.4.0.tar.gz: polyglot/frontend/Pass__24ID.h <==
// public class polyglot.frontend.Pass$ID

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3218faf4b567e7d9 polyglot_frontend_Pass__24ID
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header polyglot_util_Enum

#include "polyglot/util/Enum.h"

#ifndef _JC_polyglot_frontend_Pass__24ID_H_
#define _JC_polyglot_frontend_Pass__24ID_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_frontend_Pass__24ID$sub_refs	_jc_polyglot_frontend_Pass__24ID$sub_refs;
typedef struct _jc_polyglot_frontend_Pass__24ID$sub_nonrefs	_jc_polyglot_frontend_Pass__24ID$sub_nonrefs;
typedef struct _jc_polyglot_frontend_Pass__24ID$refs	_jc_polyglot_frontend_Pass__24ID$refs;
typedef struct _jc_polyglot_frontend_Pass__24ID$nonrefs	_jc_polyglot_frontend_Pass__24ID$nonrefs;
typedef struct _jc_polyglot_frontend_Pass__24ID$object	_jc_polyglot_frontend_Pass__24ID$object;

typedef const struct _jc_polyglot_frontend_Pass__24ID$vmethods	_jc_polyglot_frontend_Pass__24ID$vmethods;
typedef const struct _jc_polyglot_frontend_Pass__24ID$vtable	_jc_polyglot_frontend_Pass__24ID$vtable;
typedef const struct _jc_polyglot_frontend_Pass__24ID$vtype	_jc_polyglot_frontend_Pass__24ID$vtype;

// Constructors
extern void _jc_polyglot_frontend_Pass__24ID$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_polyglot_frontend_Pass__24ID$vmethods {
};

// Vtable
struct _jc_polyglot_frontend_Pass__24ID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum$vmethods	polyglot_util_Enum;
	_jc_polyglot_frontend_Pass__24ID$vmethods	polyglot_frontend_Pass__24ID;
};

// Vtype
struct _jc_polyglot_frontend_Pass__24ID$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_Pass__24ID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_Pass__24ID$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_Pass__24ID$refs {
    _jc_polyglot_frontend_Pass__24ID$sub_refs	polyglot_frontend_Pass__24ID;
    _jc_polyglot_util_Enum$sub_refs	polyglot_util_Enum;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_Pass__24ID$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_Pass__24ID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum$sub_nonrefs	polyglot_util_Enum;
    _jc_polyglot_frontend_Pass__24ID$sub_nonrefs	polyglot_frontend_Pass__24ID;
};

// Object instance structure
struct _jc_polyglot_frontend_Pass__24ID$object {
	_jc_polyglot_frontend_Pass__24ID$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_Pass__24ID$vtype	*vtype;
	_jc_polyglot_frontend_Pass__24ID$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_Pass__24ID$vtype _jc_polyglot_frontend_Pass__24ID$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_Pass__24ID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_Pass__24ID$class_object;

#endif	/* _JC_polyglot_frontend_Pass__24ID_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/Pass__24ID.h <==
// public class polyglot.frontend.Pass$ID

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3218faf4b567e7d9 polyglot_frontend_Pass__24ID
// @dep_class 82f09079602e8c27 polyglot_util_Enum

// header file dependencies
// @dep_header polyglot_util_Enum

#include "polyglot/util/Enum.h"

#ifndef _JC_polyglot_frontend_Pass__24ID_H_
#define _JC_polyglot_frontend_Pass__24ID_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_frontend_Pass__24ID$sub_refs	_jc_polyglot_frontend_Pass__24ID$sub_refs;
typedef struct _jc_polyglot_frontend_Pass__24ID$sub_nonrefs	_jc_polyglot_frontend_Pass__24ID$sub_nonrefs;
typedef struct _jc_polyglot_frontend_Pass__24ID$refs	_jc_polyglot_frontend_Pass__24ID$refs;
typedef struct _jc_polyglot_frontend_Pass__24ID$nonrefs	_jc_polyglot_frontend_Pass__24ID$nonrefs;
typedef struct _jc_polyglot_frontend_Pass__24ID$object	_jc_polyglot_frontend_Pass__24ID$object;

typedef const struct _jc_polyglot_frontend_Pass__24ID$vmethods	_jc_polyglot_frontend_Pass__24ID$vmethods;
typedef const struct _jc_polyglot_frontend_Pass__24ID$vtable	_jc_polyglot_frontend_Pass__24ID$vtable;
typedef const struct _jc_polyglot_frontend_Pass__24ID$vtype	_jc_polyglot_frontend_Pass__24ID$vtype;

// Constructors
extern void _jc_polyglot_frontend_Pass__24ID$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_frontend_Pass__24ID$vmethods {
};

// Vtable
struct _jc_polyglot_frontend_Pass__24ID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Enum$vmethods	polyglot_util_Enum;
	_jc_polyglot_frontend_Pass__24ID$vmethods	polyglot_frontend_Pass__24ID;
};

// Vtype
struct _jc_polyglot_frontend_Pass__24ID$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_Pass__24ID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_Pass__24ID$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_Pass__24ID$refs {
    _jc_polyglot_frontend_Pass__24ID$sub_refs	polyglot_frontend_Pass__24ID;
    _jc_polyglot_util_Enum$sub_refs	polyglot_util_Enum;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_Pass__24ID$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_Pass__24ID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Enum$sub_nonrefs	polyglot_util_Enum;
    _jc_polyglot_frontend_Pass__24ID$sub_nonrefs	polyglot_frontend_Pass__24ID;
};

// Object instance structure
struct _jc_polyglot_frontend_Pass__24ID$object {
	_jc_polyglot_frontend_Pass__24ID$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_Pass__24ID$vtype	*vtype;
	_jc_polyglot_frontend_Pass__24ID$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_Pass__24ID$vtype _jc_polyglot_frontend_Pass__24ID$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_Pass__24ID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_Pass__24ID$class_object;

#endif	/* _JC_polyglot_frontend_Pass__24ID_H_ */
